@@ -4,10 +4,11 @@
 #'
 #' @param x An object of class `"mixedbiastest"`.
 #' @param ... Additional arguments (currently not used).
-#' @return No return value. This function is called for its side effects (printing the results).
+#' @return The input object, returned invisibly.
 #' @method print mixedbiastest
 #' @export
 print.mixedbiastest <- function(x, ...) {
   cat("Bias Diagnostic Results:\n")
   print(x$results_table, row.names = FALSE)
+  invisible(x)
 }
